<div align="center">
  
# Gesserit

</div>

<div align="center">
  <img src="gesserit.svg" alt="drawing" style="width:200px;"/>
</div>

Inspect retrieval results.

Installation
```
pip install gesserit
```

Usage
```
```
